diff mbox

[04/16] virtio-scsi: Fix tgpt typo to tpgt and use uint16_t

Message ID 1334803149-27379-5-git-send-email-zwu.kernel@gmail.com
State New
Headers show

Commit Message

Zhiyong Wu April 19, 2012, 2:38 a.m. UTC
From: Stefan Hajnoczi <stefanha@linux.vnet.ibm.com>

Signed-off-by: Stefan Hajnoczi <stefanha@linux.vnet.ibm.com>
Signed-off-by: Zhi Yong Wu <wuzhy@linux.vnet.ibm.com>
---
 hw/virtio-scsi.h |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
diff mbox

Patch

diff --git a/hw/virtio-scsi.h b/hw/virtio-scsi.h
index 9cddacb..f66d12c 100644
--- a/hw/virtio-scsi.h
+++ b/hw/virtio-scsi.h
@@ -40,9 +40,9 @@  struct vhost_vring_target {
 };
 
 typedef struct {
     /* The tcm_vhost wwpn and tgpt */
     char *wwpn;
-    char *tgpt;
+    uint16_t tpgt;
 } VirtIOSCSIConf;
 
 #endif /* _QEMU_VIRTIO_SCSI_H */
@@ -40,9 +40,9 @@  struct vhost_vring_target {
 
 typedef struct {
-    /* The tcm_vhost wwpn and tgpt */
+    /* The tcm_vhost wwpn and tpgt */
     char *wwpn;